==> eiffelstudio-18.11.10.2592.tar: F_code/C29/gb1439.c <==
/*
 * Code for class GB_INTEGER_CONSTANT
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "gb1439.h"
#include "eif_built_in.h"
#include "eif_out.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {GB_INTEGER_CONSTANT}.make_with_name_and_value */
void F2242_25524 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_REFERENCE arg3)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,arg3);
	RTLR(2,arg1);
	RTLR(3,tr1);
	RTLIU(4);
	
	RTEAA("make_with_name_and_value", 2241, Current, 0, 3, 31441);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg3);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg3;
	RTHOOK(2);
	tr1 = (EIF_REFERENCE) eif_builtin_ANY_twin (arg1);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	RTHOOK(3);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_4_0_0_0_) = (EIF_INTEGER_32) arg2;
	RTHOOK(4);
	{
		static EIF_TYPE_INDEX typarr0[] = {1144,75,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F1145_10766(RTCW(tr1), ((EIF_INTEGER_32) 4L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) tr1;
	RTHOOK(8);
	RTLE;
	RTEE;
}

/* {GB_INTEGER_CONSTANT}.type */
static EIF_REFERENCE F2242_25525_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	

	
	RTEAA("type", 2241, Current, 0, 0, 31442);
	RTOSP (25525);
#define Result RTOSR(25525)
	RTOC_NEW(Result);
	RTHOOK(1);
	Result = RTOSCF(21204,F1926_21204,(Current));
	RTOSE (25525);
	RTHOOK(2);
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F2242_25525 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(25525,F2242_25525_body,(Current));
}

/* {GB_INTEGER_CONSTANT}.value_as_string */
EIF_REFERENCE F2242_25527 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 ti4_1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLIU(2);
	
	RTEAA("value_as_string", 2241, Current, 0, 0, 31444);
	RTGC;
	RTHOOK(1);
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_4_0_0_0_);
	Result = c_outi(ti4_1);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {GB_INTEGER_CONSTANT}.as_multi_column_list_row */
EIF_REFERENCE F2242_25528 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,tr1);
	RTLR(1,Result);
	RTLR(2,Current);
	RTLIU(3);
	
	RTEAA("as_multi_column_list_row", 2241, Current, 0, 0, 31445);
	RTGC;
	RTHOOK(1);
	tr1 = RTLNS(eif_new_type(1526, 0x00).id, 1526, _OBJSIZ_7_2_0_2_0_0_0_0_);
	F1304_11843(RTCW(tr1));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTOSCF(8320,F616_8320,(Current));
	tr1 = F886_9051(RTCW(tr1), ((EIF_INTEGER_32) 1L));
	F1322_12095(RTCW(Result), tr1);
	RTHOOK(3);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	tr1 = F1470_13703(RTCW(tr1));
	F1170_10956(RTCW(Result), tr1);
	RTHOOK(4);
	tr1 = RTOSCF(25525,F2242_25525,(Current));
	tr1 = F1470_13703(RTCW(tr1));
	F1170_10956(RTCW(Result), tr1);
	RTHOOK(5);
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_4_0_0_0_);
	tr1 = c_outi(ti4_1);
	tr1 = F1470_13703(RTCW(tr1));
	F1170_10956(RTCW(Result), tr1);
	RTHOOK(6);
	F1304_11845(RTCW(Result), Current);
	RTHOOK(7);
	RTLE;
	RTEE;
	return Result;
}

/* {GB_INTEGER_CONSTANT}.can_modify_to_value */
EIF_BOOLEAN F2242_25530 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTCFDT;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc1);
	RTLR(3,loc2);
	RTLIU(4);
	
	RTEAA("can_modify_to_value", 2241, Current, 2, 1, 31447);
	RTGC;
	RTHOOK(1);
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTHOOK(2);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	F1145_10797(RTCW(tr1));
	for (;;) {
		RTHOOK(3);
		tb1 = '\01';
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
		tb2 = F903_9141(RTCW(tr1));
		if (!tb2) {
			tb1 = (EIF_BOOLEAN) !Result;
		}
		if (tb1) break;
		RTHOOK(4);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
		loc1 = F1145_10771(RTCW(tr1));
		RTHOOK(5);
		loc2 = F2236_25475(Current, loc1);
		loc2 = *(EIF_REFERENCE *)(RTCW(loc2) + O23232[Dtype(loc2)-2451]);
		tr1 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_3_);
		loc2 = F1134_10640(RTCW(loc2), tr1);
		{
			static EIF_TYPE_INDEX typarr0[] = {1466,0xFFF9,1,1390,1396,1429,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
			loc2 = RTRV(typres0, loc2);
		}
		
		RTHOOK(7);
		tb2 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_POINTER, EIF_REFERENCE, EIF_INTEGER_32)) *(EIF_POINTER *)(RTCW(loc2)+ _PTROFF_4_3_0_3_0_0_))(
			*(EIF_POINTER *)(RTCW(loc2)+ _PTROFF_4_3_0_3_0_1_),
			*(EIF_REFERENCE *)(RTCW(loc2) + _REFACS_1_), arg1);
		*(EIF_BOOLEAN *)(RTCW(loc2)+ _CHROFF_4_2_) = tb2;
		;
		tb2 = tb2;
		RTHOOK(8);
		Result = *(EIF_BOOLEAN *)(RTCW(loc2)+ _CHROFF_4_2_);
		RTHOOK(9);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
		F1145_10799(RTCW(tr1));
	}
	RTHOOK(10);
	RTLE;
	RTEE;
	return Result;
}

/* {GB_INTEGER_CONSTANT}.modify_value */
void F2242_25531 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	RTCFDT;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc1);
	RTLR(3,loc2);
	RTLIU(4);
	
	RTEAA("modify_value", 2241, Current, 2, 1, 31448);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	F1145_10797(RTCW(tr1));
	for (;;) {
		RTHOOK(2);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
		tb1 = F903_9141(RTCW(tr1));
		if (tb1) break;
		RTHOOK(3);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
		loc1 = F1145_10771(RTCW(tr1));
		RTHOOK(4);
		loc2 = F2236_25475(Current, loc1);
		loc2 = *(EIF_REFERENCE *)(RTCW(loc2) + O23233[Dtype(loc2)-2451]);
		tr1 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_3_);
		loc2 = F1134_10640(RTCW(loc2), tr1);
		{
			static EIF_TYPE_INDEX typarr0[] = {1464,0xFFF9,1,1390,1396,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
			loc2 = RTRV(typres0, loc2);
		}
		
		RTHOOK(6);
		(FUNCTION_CAST(void, (EIF_POINTER, EIF_REFERENCE, EIF_INTEGER_32)) *(EIF_POINTER *)(RTCW(loc2)+ _PTROFF_4_2_0_3_0_0_))(
			*(EIF_POINTER *)(RTCW(loc2)+ _PTROFF_4_2_0_3_0_1_),
			*(EIF_REFERENCE *)(RTCW(loc2) + _REFACS_1_), arg1);
		;
		RTHOOK(7);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
		F1145_10799(RTCW(tr1));
	}
	RTHOOK(8);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_4_0_0_0_) = (EIF_INTEGER_32) arg1;
	RTHOOK(10);
	RTLE;
	RTEE;
}

void EIF_Minit1439 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C29/gb1439.c <==
/*
 * Code for class GB_INTEGER_CONSTANT
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "gb1439.h"
#include "eif_built_in.h"
#include "eif_out.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {GB_INTEGER_CONSTANT}.make_with_name_and_value */
void F2246_25541 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_REFERENCE arg3)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,arg3);
	RTLR(2,arg1);
	RTLR(3,tr1);
	RTLIU(4);
	
	RTEAA("make_with_name_and_value", 2245, Current, 0, 3, 31480);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg3);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg3;
	RTHOOK(2);
	tr1 = (EIF_REFERENCE) eif_builtin_ANY_twin (arg1);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	RTHOOK(3);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_4_0_0_0_) = (EIF_INTEGER_32) arg2;
	RTHOOK(4);
	{
		static EIF_TYPE_INDEX typarr0[] = {1146,77,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F1147_10791(RTCW(tr1), ((EIF_INTEGER_32) 4L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) tr1;
	RTHOOK(8);
	RTLE;
	RTEE;
}

/* {GB_INTEGER_CONSTANT}.type */
static EIF_REFERENCE F2246_25542_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	

	
	RTEAA("type", 2245, Current, 0, 0, 31481);
	RTOSP (25542);
#define Result RTOSR(25542)
	RTOC_NEW(Result);
	RTHOOK(1);
	Result = RTOSCF(21242,F1928_21242, (Current));
	RTOSE (25542);
	RTHOOK(2);
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F2246_25542 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(25542,F2246_25542_body,(Current));
}

/* {GB_INTEGER_CONSTANT}.value_as_string */
EIF_REFERENCE F2246_25544 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 ti4_1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLIU(2);
	
	RTEAA("value_as_string", 2245, Current, 0, 0, 31474);
	RTGC;
	RTHOOK(1);
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_4_0_0_0_);
	Result = c_outi(ti4_1);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {GB_INTEGER_CONSTANT}.as_multi_column_list_row */
EIF_REFERENCE F2246_25545 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Result);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEAA("as_multi_column_list_row", 2245, Current, 0, 0, 31475);
	RTGC;
	RTHOOK(1);
	Result = RTLNS(eif_new_type(1528, 0x00).id, 1528, _OBJSIZ_7_2_0_2_0_0_0_0_);
	F1307_11871(RTCW(Result));
	RTHOOK(2);
	tr1 = RTOSCF(8338,F618_8338, (Current));
	tr1 = F888_9071(RTCW(tr1), ((EIF_INTEGER_32) 1L));
	F1325_12123(RTCW(Result), tr1);
	RTHOOK(3);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	tr1 = F1473_13747(RTCW(tr1));
	F1172_10981(RTCW(Result), tr1);
	RTHOOK(4);
	tr1 = RTOSCF(25542,F2246_25542, (Current));
	tr1 = F1473_13747(RTCW(tr1));
	F1172_10981(RTCW(Result), tr1);
	RTHOOK(5);
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_4_0_0_0_);
	tr1 = c_outi(ti4_1);
	tr1 = F1473_13747(RTCW(tr1));
	F1172_10981(RTCW(Result), tr1);
	RTHOOK(6);
	F1307_11873(RTCW(Result), Current);
	RTHOOK(7);
	RTLE;
	RTEE;
	return Result;
}

/* {GB_INTEGER_CONSTANT}.can_modify_to_value */
EIF_BOOLEAN F2246_25547 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTCFDT;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc1);
	RTLR(3,loc2);
	RTLIU(4);
	
	RTEAA("can_modify_to_value", 2245, Current, 2, 1, 31477);
	RTGC;
	RTHOOK(1);
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	RTHOOK(2);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	F1147_10822(RTCW(tr1));
	for (;;) {
		RTHOOK(3);
		tb1 = '\01';
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
		tb2 = F905_9161(RTCW(tr1));
		if (!tb2) {
			tb1 = (EIF_BOOLEAN) !Result;
		}
		if (tb1) break;
		RTHOOK(4);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
		loc1 = F1147_10796(RTCW(tr1));
		RTHOOK(5);
		loc2 = F2243_25523(Current, loc1);
		loc2 = *(EIF_REFERENCE *)(RTCW(loc2) + O23270[Dtype(loc2)-2458]);
		tr1 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_3_);
		loc2 = F1136_10665(RTCW(loc2), tr1);
		{
			static EIF_TYPE_INDEX typarr0[] = {1469,0xFFF9,1,1393,1399,1432,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
			loc2 = RTRV(typres0, loc2);
		}
		
		RTHOOK(7);
		tb2 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_POINTER, EIF_REFERENCE, EIF_INTEGER_32)) *(EIF_POINTER *)(RTCW(loc2)+ _PTROFF_4_3_0_3_0_0_))(
			*(EIF_POINTER *)(RTCW(loc2)+ _PTROFF_4_3_0_3_0_1_),
			*(EIF_REFERENCE *)(RTCW(loc2) + _REFACS_1_), arg1);
		*(EIF_BOOLEAN *)(RTCW(loc2)+ _CHROFF_4_2_) = tb2;
		tb2 = tb2;
		RTHOOK(8);
		Result = *(EIF_BOOLEAN *)(RTCW(loc2)+ _CHROFF_4_2_);
		RTHOOK(9);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
		F1147_10824(RTCW(tr1));
	}
	RTHOOK(10);
	RTLE;
	RTEE;
	return Result;
}

/* {GB_INTEGER_CONSTANT}.modify_value */
void F2246_25548 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	RTCFDT;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc1);
	RTLR(3,loc2);
	RTLIU(4);
	
	RTEAA("modify_value", 2245, Current, 2, 1, 31478);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	F1147_10822(RTCW(tr1));
	for (;;) {
		RTHOOK(2);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
		tb1 = F905_9161(RTCW(tr1));
		if (tb1) break;
		RTHOOK(3);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
		loc1 = F1147_10796(RTCW(tr1));
		RTHOOK(4);
		loc2 = F2243_25523(Current, loc1);
		loc2 = *(EIF_REFERENCE *)(RTCW(loc2) + O23271[Dtype(loc2)-2458]);
		tr1 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_3_);
		loc2 = F1136_10665(RTCW(loc2), tr1);
		{
			static EIF_TYPE_INDEX typarr0[] = {1467,0xFFF9,1,1393,1399,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
			loc2 = RTRV(typres0, loc2);
		}
		
		RTHOOK(6);
		(FUNCTION_CAST(void, (EIF_POINTER, EIF_REFERENCE, EIF_INTEGER_32)) *(EIF_POINTER *)(RTCW(loc2)+ _PTROFF_4_2_0_3_0_0_))(
			*(EIF_POINTER *)(RTCW(loc2)+ _PTROFF_4_2_0_3_0_1_),
			*(EIF_REFERENCE *)(RTCW(loc2) + _REFACS_1_), arg1);
		RTHOOK(7);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
		F1147_10824(RTCW(tr1));
	}
	RTHOOK(8);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_4_0_0_0_) = (EIF_INTEGER_32) arg1;
	RTHOOK(10);
	RTLE;
	RTEE;
}

void EIF_Minit1439 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
